A small sample of the Enron corpus comprising ten authors with approximately the same amount of data. The data was pre-processed using the POSnoise algorithm to mask content (see contentmask()).
A small sample of the Enron corpus comprising ten authors with approximately the same amount of data. The data was pre-processed using the POSnoise algorithm to mask content (see contentmask()).