Learn R Programming

idiolect (version 1.2.0)

enron.sample: Enron sample

Description

A small sample of the Enron corpus comprising ten authors with approximately the same amount of data. The data was pre-processed using the POSnoise algorithm to mask content (see contentmask()).

Usage

enron.sample

Arguments

Format

A quanteda corpus object.